/*
 * Copyright (c) 2003-2009 jMonkeyEngine
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * * Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * * Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 *
 * * Neither the name of 'jMonkeyEngine' nor the names of its contributors
 *   may be used to endorse or promote products derived from this software
 *   without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.jmex.model.ogrexml.anim;

import com.jme.util.export.InputCapsule;
import com.jme.util.export.JMEExporter;
import com.jme.util.export.JMEImporter;
import com.jme.util.export.OutputCapsule;
import com.jme.util.export.Savable;
import com.jmex.model.ogrexml.anim.PoseTrack.PoseFrame;

import java.io.IOException;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

public class MeshAnimation implements Serializable, Savable {

    private static final long serialVersionUID = 1L;

    private String name;
    private float length;
    private Track[] tracks;

    public MeshAnimation(String name, float length){
        this.name = name;
        this.length = length;
    }

    public String getName(){
        return name;
    }

    public float getLength(){
        return length;
    }

    public void setTracks(Track[] tracks){
        this.tracks = tracks;
    }

    public Track[] getTracks(){
        return tracks;
    }

    public void setTime(float time, OgreMesh[] targets, float weight){
        for (int i = 0; i < tracks.length; i++){
            tracks[i].setTime(time, targets, weight);
        }
    }


    public void write(JMEExporter e) throws IOException {
        OutputCapsule out = e.getCapsule(this);
        out.write(name, "name", "");
        out.write(length, "length", -1f);
        out.write(tracks, "tracks", null);
    }


    public void read(JMEImporter i) throws IOException {
        InputCapsule in = i.getCapsule(this);
        name = in.readString("name", "");
        length = in.readFloat("length", -1f);
        tracks = (Track[]) in.readSavableArray("tracks", null);
    }


    public Class getClassTag() {
        return MeshAnimation.class;
    }
    
    /**
     * 
     * Returns a List of PoseFrames that let you access
     * all weights of all submeshes
     * 
     * @param time
     * @return List<PoseFrame>
     */
    public List<PoseFrame> getPoseWeightFrame(float time)
    {
    	ArrayList<PoseFrame> result = new ArrayList<PoseFrame>();
    	for (Track track : tracks)
    	{
    		for (int i=0;i<((PoseTrack)track).getFrames().length;i++)
    		{
    			if (((PoseTrack)track).getTimes()[i]==time)
    			{
    				result.add(((PoseTrack)track).getFrames()[i]);
    				break;
    			}
    		}
    	}
    	return result;
    }
    
	public void setWeight(String poseName,List<PoseFrame> frameList,float weight)
	{
		for (PoseFrame p : frameList)
		{
			for (int i=0;i<p.getPoses().length;i++)
			{
				if (p.getPoses()[i].getName().startsWith(poseName))
				{
					p.getWeights()[i]=weight;
				}
			}
		}
	}

}
